# ewokssphinx

A set of Sphinx directives for Ewoks

## Quick start

```bash
pip install ewokssphinx
```

Then, add `ewokssphinx` to the list of `extensions` in the Sphinx configuration file:

```python
# conf.py

...

extensions = [
    ...,
    "ewokssphinx"
]
```

## Documentation

[Full documentation](https://ewokssphinx.readthedocs.io/en/latest) with [examples](https://ewokssphinx.readthedocs.io/en/latest/examples.html)
